--[[
Name: TreatOrTreat
Revision: r20090206005809
Author(s): falconindy
Description: Warnings for targets and recipient rogues of Tricks of the Trade.
Inspired by: SimpleMD and Misdrection Helper
]]

--local ver, rev = "1.0", tonumber(("$Revision: 5 $"):match("%d+"))
--local addonID = "TrickOrTreat-" .. ver .. " r" .. rev 
local ClassColor = {
	["DEATHKNIGHT"] = "|cffc41f3b",
	["DRUID"] = "|cffff7d0a",
	["HUNTER"] = "|cffabd473",
	["MAGE"] = "|cff69ccf0",
	["PALADIN"] = "|cfff58cba",
	["PRIEST"] = "|cffffffff",
	["ROGUE"] = "|cfffff569",
	["SHAMAN"] = "|cff2459ff",
	["WARLOCK"] = "|cff9482c9",
	["WARRIOR"] = "|cffc79c6e",
}

local UnitDetailedThreatSituation = UnitDetailedThreatSituation
local UnitExists = UnitExists
local mfloor = math.floor

--Addon Declaration
ToT = LibStub("AceAddon-3.0"):NewAddon("TreatOrTreat", "AceEvent-3.0", "AceConsole-3.0", "LibSink-2.0")

--Register Event on Enable
function ToT:OnEnable()
	self:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")

	self:SetSinkStorage({ ["sink20OutputSink"] = "RaidWarning" })

	dmgCounter_self = 0
	dmgCounter_target = 0
	parse_dmg_self = false
	parse_dmg_target = false
	last_tricked = nil
	pName = UnitName("player")

end

--Unregister Event on Disable
function ToT:OnDisable()
	self:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end

function ToT:COMBAT_LOG_EVENT_UNFILTERED(event, _, subevent, _,sourceName, _, _, destName, _, spellID, spellName, _, arg12)
	if spellID == 57933 then
		if subevent == "SPELL_AURA_APPLIED" and sourceName == pName then
			local themessage = "Trick or Treat!"
			if UnitExists("target") then
				local isTanking,_,threatpct,_,threatvalue = UnitDetailedThreatSituation(destName, "target");
				if threatvalue == nil then threatvalue, threatpct = 0, 0 end
				threatpct = threatpct * 1.1
				local rawtotank = threatvalue * (100 / threatpct - 1)
				if not isTanking and (threatpct > 50 or rawtotank <= 20000) then
					threatpct = tostring(mfloor(threatpct))
					themessage = themessage.." Careful! You're at "..threatpct.."% threat on "..UnitName("target").."."
				end
			end
			SendChatMessage(themessage, "WHISPER", nil, destName)
			parse_dmg_target = true
		elseif subevent == "SPELL_AURA_APPLIED" and destName == pName then
			self:Pour(sourceName.." tricked you!")
			PlaySoundFile("Interface\\AddOns\\TrickOrTreat\\sounds\\alert.mp3")
		end
	end
	if spellID == 57934 then
		if subevent == "SPELL_CAST_SUCCESS" and sourceName == pName then
			last_tricked = destName
			parse_dmg_self = true
			self:Pour("|cffff6600[Trick or Treat] "..ClassColor[select(2, UnitClass(destName))]..destName.."|r")
		end
	end
	if spellID == 59628 and subevent == "SPELL_AURA_REMOVED" then
		if destName == pName then
			extra_dmg = mfloor(dmgCounter_target - dmgCounter_target/1.15)
			self:Print(dmgCounter_self.." damage dealt during Tricks. Target did "..extra_dmg.." extra.")
			SendChatMessage("Tricks gave you "..extra_dmg.." extra damage.", "WHISPER", nil, last_tricked)

			parse_dmg_target = false
			parse_dmg_self = false
			dmgCounter_self = 0
			dmgCounter_target = 0
		end
	end

--DAMAGE PARSING HANDLERS
	if parse_dmg_self then
		if (subevent == "SPELL_DAMAGE" or subevent == "SPELL_PERIODIC_DAMAGE") and sourceName == pName then
			--dmgCounter_self = dmgCounter_self + arg12 - arg13
			dmgCounter_self = self:AddDamage(dmgCounter_self, arg12, arg13)
		elseif subevent == "SWING_DAMAGE" and sourceName == pName then
			--dmgCounter_self = dmgCounter_self + arg9 - arg10
			dmgCounter_self = self:AddDamage(dmgCounter_self, arg9, arg10)
		end
	end

	if parse_dmg_target then
		if (subevent == "SPELL_DAMAGE" or subevent == "SPELL_PERIODIC_DAMAGE") and sourceName == last_tricked then
			--dmgCounter_target = dmgCounter_target + arg12 - arg13
			dmgCounter_target = self:AddDamage(dmgCounter_target, arg12, arg13)
		elseif subevent == "SWING_DAMAGE" and sourceName == pName then
			--dmgCounter_target = dmgCounter_target + arg9 - arg10
			dmgCounter_target = self:AddDamage(dmgCounter_target, arg9, arg10)
		end
	end
end

do
	function ToT:AddDamage(counter, damage, overkill)
		return counter + damage - overkill
	end
end
